import React, { useState, useRef, useEffect } from 'react'
import TableView from '@/components/TableView';
import { Form, Input, Button, Divider } from '@arco-design/web-react';
import * as $$ from '@/utils/utility';

const FormItem = Form.Item;
const formItemLayout = {
  labelCol: {
    span: 4,
  },
  wrapperCol: {
    span: 17,
  },
};

//法人
function getCompany(data) {
  return $$.ax.request({ url: `grid/company/pageQuery`, type: 'get', service: 'sys', data });
}

export default function SelectUnitDialog(props) {
  const formRef = useRef();
  const [search, setSearch] = useState({ page: 1, size: 10 });
  const [data, setData] = useState({
    tableData: [],
    total: 0
  });
  const [loading, setLoading] = useState(false)

  // 列配置
  const fakeColumns = [
    {
      title: '单位名称',
      dataIndex: 'trueName',
      key: 'trueName',
      width: 150
    },
    {
      title: '单位类型',
      dataIndex: 'unitType',
      key: 'unitType',
      render: () => {
        return <div>{props.perClass == '09_01001-2' ? '企业' : '非法人组织'}</div>
      },
      width: 150
    },
    {
      title: props.perClass == '09_01001-2' ? '统一社会信用代码' : '组织机构代码',
      dataIndex: 'orgaCode',
      key: 'orgaCode',
      width: 250
    },
    {
      title: '单位所在地',
      dataIndex: 'addr',
      key: 'addr',
      width: 150
    },
    {
      title: '操作',
      dataIndex: 'actions',
      key: 'actions',
      width: 120,
      render: (text, record) => (
        <div style={{ display: 'flex', color: '#1A6FB8', gap: '16px', cursor: 'pointer' }}>
          <div onClick={() => { handleSelect(record) }}>选择</div>
        </div>
      )
    },
  ];

  useEffect(() => {
    getTableData()
  }, [])

  useEffect(() => {
    getTableData()
  }, [search])

  //表格数据请求
  const getTableData = async () => {
    setLoading(true)
    let res
    if (props.perClass == '09_01001-2') {
      //法人
      res = await getCompany({
        ...search
      })
    } else {
      //非法人组织
    }
    if (res.type) {
      setLoading(false)
      setData({
        tableData: res.data.content,
        total: res.data.totalElements
      })
    }
  }

  //查询
  const handleSUbmit = () => {
    const data = formRef.current.getFieldsValue();
    setSearch({
      ...search,
      ...data,
      page: 1
    })
  }

  //选择
  const handleSelect = (record) => {
    props.selectData(record)
  }

  return (
    <div
      style={{ marginBottom: '20px' }}
      onKeyUp={(e) => {
        if (e.key === 'Enter') {
          handleSUbmit()
        }
      }}
    >
      <Form
        ref={formRef}
        requiredSymbol={false}
        layout='inline'
        {...formItemLayout}
      >
        <FormItem
          label='单位名称：'
          field='integratedQuery'
          className='integratedQuery'
        >
          <Input placeholder='请填写' style={{ width: '100%' }} />
        </FormItem>
        <Button
          style={{ marginRight: '20px' }}
          type="primary"
          onClick={handleSUbmit}
        >
          查询
        </Button>
        <Button
          onClick={() => {
            formRef.current.resetFields();
            setSearch({
              page: search.page,
              size: search.size
            })
          }}
        >
          重置
        </Button>
      </Form>
      <Divider />
      <div className='unitDialogResult'>
        查询结果
      </div>
      <TableView
        columns={fakeColumns}
        dataSource={data.tableData}
        size="small"
        rowKey="id"
        bordered={true}
        isScroll={true}//兼容以前的，当需要表格竖向滚动，请设置这个
        tableHeight={460}
        loading={loading}
        pagination={{
          current: search.page,
          pageSize: search.size,
          total: data.total,
          onChange: (page, pageSize) => {
            setSearch({
              ...search,
              page,
              size: pageSize
            })
          },
        }}
      />
    </div>
  )
}
